@@ -572,22 +572,25 @@ def test_parser_squashed_commit_github_squash_style(
 @pytest.mark.parametrize(
     "commit_message, bump",
     [
-        ("feat(parsers): Add new parser pattern\n\nBREAKING CHANGE: ", LevelBump.MAJOR),
-        ("feat(parsers)!: Add new parser pattern", LevelBump.MAJOR),
         (
-            "feat(parsers): Add new parser pattern\n\nNew pattern is awesome\n\n"
-            "BREAKING CHANGE: \n",
+            "feat(parsers): add new parser pattern\n\nBREAKING CHANGE: change",
+            LevelBump.MAJOR,
+        ),
+        ("feat(parsers)!: add new parser pattern", LevelBump.MAJOR),
+        (
+            "feat(parsers): add new parser pattern\n\nNew pattern is awesome\n\n"
+            "BREAKING CHANGE: change \n",
             LevelBump.MAJOR,
         ),
         (
-            "feat(parsers): Add new parser pattern\n\nBREAKING-CHANGE: change !",
+            "feat(parsers): add new parser pattern\n\nBREAKING-CHANGE: change !",
             LevelBump.MAJOR,
         ),
-        ("feat(parser): Add emoji parser", LevelBump.MINOR),
-        ("fix(parser): Fix regex in angular parser", LevelBump.PATCH),
-        ("test(parser): Add a test for angular parser", LevelBump.NO_RELEASE),
-        ("feat(parser)!: Edit data parsing stuff", LevelBump.MAJOR),
-        ("fix!: Edit data parsing stuff again", LevelBump.MAJOR),
+        ("feat(parser): add emoji parser", LevelBump.MINOR),
+        ("fix(parser): fix regex in angular parser", LevelBump.PATCH),
+        ("test(parser): add a test for angular parser", LevelBump.NO_RELEASE),
+        ("feat(parser)!: edit data parsing stuff", LevelBump.MAJOR),
+        ("fix!: edit data parsing stuff again", LevelBump.MAJOR),
         ("fix: superfix", LevelBump.PATCH),
     ],
 )
@@ -675,15 +678,15 @@ _footer = "Closes: #400"
 @pytest.mark.parametrize(
     "message, descriptions",
     [
-        ("feat(parser): Add emoji parser", ["Add emoji parser"]),
-        ("fix(parser): Fix regex in angular parser", ["Fix regex in angular parser"]),
+        ("feat(parser): add emoji parser", ["add emoji parser"]),
+        ("fix(parser): fix regex in angular parser", ["fix regex in angular parser"]),
         (
-            "test(parser): Add a test for angular parser",
-            ["Add a test for angular parser"],
+            "test(parser): add a test for angular parser",
+            ["add a test for angular parser"],
         ),
         (
-            f"fix(tox): Fix env \n\n{_long_text}\n\n{_footer}",
-            ["Fix env ", _long_text, _footer],
+            f"fix(tox): fix env \n\n{_long_text}\n\n{_footer}",
+            ["fix env ", _long_text, _footer],
         ),
         ("fix: superfix", ["superfix"]),
     ],
@@ -1041,13 +1044,95 @@ def test_parser_return_linked_issues_from_commit_message(
     assert tuple(linked_issues) == result.linked_issues
 
 
+@pytest.mark.parametrize(
+    "message, notices",
+    [
+        pytest.param(
+            message,
+            notices,
+            id=test_id,
+        )
+        for test_id, message, notices in [
+            (
+                "single notice",
+                dedent(
+                    """\
+                    fix(parser): fix regex in angular parser
+
+                    NOTICE: This is a notice
+                    """
+                ),
+                ["This is a notice"],
+            ),
+            (
+                "multiline notice",
+                dedent(
+                    """\
+                    fix(parser): fix regex in angular parser
+
+                    NOTICE: This is a notice that is longer than
+                    other notices
+                    """
+                ),
+                ["This is a notice that is longer than other notices"],
+            ),
+            (
+                "multiple notices",
+                dedent(
+                    """\
+                    fix(parser): fix regex in angular parser
+
+                    NOTICE: This is a notice
+
+                    NOTICE: This is a second notice
+                    """
+                ),
+                ["This is a notice", "This is a second notice"],
+            ),
+            (
+                "notice with other footer",
+                dedent(
+                    """\
+                    fix(parser): fix regex in angular parser
+
+                    BREAKING CHANGE: This is a breaking change
+
+                    NOTICE: This is a notice
+                    """
+                ),
+                ["This is a notice"],
+            ),
+        ]
+    ],
+)
+def test_parser_return_release_notices_from_commit_message(
+    default_angular_parser: AngularCommitParser,
+    message: str,
+    notices: Sequence[str],
+    make_commit_obj: MakeCommitObjFn,
+):
+    parsed_results = default_angular_parser.parse(make_commit_obj(message))
+
+    assert isinstance(parsed_results, Iterable)
+    assert len(parsed_results) == 1
+
+    result = next(iter(parsed_results))
+    assert isinstance(result, ParsedCommit)
+    assert tuple(notices) == result.release_notices
+
+    # TODO: v10, remove this
+    # full_description = str.join("\n\n", result.descriptions)
+    # full_notice = str.join("\n\n", result.release_notices)
+    # assert full_notice not in full_description
+
+
 ##############################
 # test custom parser options #
 ##############################
 def test_parser_custom_default_level(make_commit_obj: MakeCommitObjFn):
     options = AngularParserOptions(default_bump_level=LevelBump.MINOR)
     parsed_results = AngularCommitParser(options).parse(
-        make_commit_obj("test(parser): Add a test for angular parser")
+        make_commit_obj("test(parser): add a test for angular parser")
     )
 
     assert isinstance(parsed_results, Iterable)
@@ -1129,3 +1214,31 @@ def test_parser_custom_patch_tags(make_commit_obj: MakeCommitObjFn):
     result = next(iter(parsed_results))
     assert isinstance(result, ParsedCommit)
     assert result.bump is LevelBump.PATCH
+
+
+def test_parser_ignore_merge_commit(
+    default_angular_parser: AngularCommitParser,
+    make_commit_obj: MakeCommitObjFn,
+):
+    # Setup: Enable parsing of linked issues
+    parser = AngularCommitParser(
+        options=AngularParserOptions(
+            **{
+                **default_angular_parser.options.__dict__,
+                "ignore_merge_commits": True,
+            }
+        )
+    )
+
+    base_commit = make_commit_obj("Merge branch 'fix/fix-feature' into 'main'")
+    incomming_commit = make_commit_obj("feat: add a new feature")
+
+    # Setup: Create a merge commit
+    merge_commit = make_commit_obj("Merge branch 'feat/add-new-feature' into 'main'")
+    merge_commit.parents = [base_commit, incomming_commit]
+
+    # Action
+    parsed_result = parser.parse(merge_commit)
+
+    assert isinstance(parsed_result, ParseError)
+    assert "Ignoring merge commit" in parsed_result.error
